package
Version:
v0.0.0-...-4f2d17f
Opens a new window with list of versions in this module.
Published: Feb 6, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Response struct {
Status string `json:"status"`
Message string `json:"message"`
Errors []string `json:"errors,omitempty"`
}
Response is a custom error response sent back to the client.
It avoids leaking internal error details.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.